@@ -1,8 +1,8 @@
 import fs from 'fs';
 import path from 'path';
 import os from 'os';
-import {serial as test} from 'ava';
-import Configstore from '.';
+import test from 'ava';
+import Configstore from './index.js';
 
 const configstorePath = new Configstore('configstore-test').path;
 
@@ -139,3 +139,14 @@ test('the store is NOT created until write', t => {
 	config.set('foo', 'bar');
 	t.true(fs.existsSync(config.path));
 });
+
+test('ensure necessary sub-directories are created', t => {
+	const customPath = path.join(fs.mkdtempSync(path.join(os.tmpdir(), 'configstore-recursive-')), 'foo', 'bar', 'baz.json');
+	const config = new Configstore('ignored-namespace', undefined, {
+		globalConfigPath: true,
+		configPath: customPath
+	});
+	t.false(fs.existsSync(config.path));
+	config.set('foo', 'bar');
+	t.true(fs.existsSync(config.path));
+});
